#ifndef __SUPERPEN_PROTOCOL_DEFS_H__
#define __SUPERPEN_PROTOCOL_DEFS_H__

// This file contains the Superpen protocol definitions as provided by UC-Logic.
// I assume all information in here is Copyright UC-Logic

// Status bits

#define	SP_BYTE_HIBIT					0x80
#define SP_BYTE_HIBIT_MASK				0x7F

#define SP_STATUS_BUTTON1				0x01
#define SP_STATUS_BUTTON2				0x02
#define SP_STATUS_BUTTON3				0x04
#define SP_STATUS_OUT_OF_PROX			0x40
#define SP_STATUS_PRESSUE_MASK			0x18
#define SP_STATUS_TABLET_MASK			0x20

// Check the state of a bit pattern
#define		BCHK(a,b)	(( a & b ) == b)

// Used to decode the X and Y dimensions from the 14 byte packed mode.  
// This works for both the X and Y
// Usage BUILD_DIMENSION_2(lobyte,hibyte)
#define		BUILD_DIMENSION_2(a,b)	( (a & SP_BYTE_HIBIT_MASK) | (( b & SP_BYTE_HIBIT_MASK) << 7 ) )

// Used to decode the pressure from a given protocol packet.
// Usage: BUILD_PRESSURE(statusbyte, pressurebyte)
#define		BUILD_PRESSURE(a,b)		( ((a & SP_STATUS_PRESSUE_MASK) >> 3 ) | (( b & SP_BYTE_HIBIT_MASK ) << 2 ) )


//Commands

//Origin Commands
#define SP_ORIGIN_UPPER_LEFT			0x62
#define SP_ORIGIN_LOWER_LEFT			0x63

//Reporting Modes
#define SP_REPORT_STREAM_MODE			0x40
#define SP_REPORT_SWITCH_STREAM_MODE	0x41
#define SP_REPORT_POINT_MODE			0x42
#define SP_REPORT_REQUEST_MODE			0x44
#define SP_REPORT_REQUEST_COMMAND		0x50

#define SP_REPORT_INCREMENT_MODE		0x49

#define SP_REPORT_AXIS_UPDATE_MODE		0x47

#define SP_REPORT_ABSOLUTE				0x46

#define SP_REPORT_DELTA_MODE			0x45

#define SP_REPORT_PRESSURE				0x36

//Reporting Rates
#define SP_REPORT_RATE_MAX				0x51
#define SP_REPORT_RATE_HALF				0x52
#define SP_REPORT_RATE_EIGTH			0x53
#define SP_REPORT_RATE_32ND				0x54

//Resolution
//Metric Resolutions
#define SP_RES_10LPMM					0x66
#define SP_RES_20LPMM					0x69
#define SP_RES_40LPMM					0x71
//Imperial Resolutions
#define SP_RES_100LPI					0x64
#define SP_RES_200LPI					0x65
#define SP_RES_400LPI					0x67
#define SP_RES_500LPI					0x68
#define SP_RES_1000LPI					0x6A
//Extended resolutions
#define SP_RES_2000LPI					0x75
#define SP_RES_2540LPI					0x79
#define SP_RES_3048LPI					0x6F
#define SP_RES_4064LPI					0x6D

//Grid Roundoff (whatever that means)
#define SP_GRO_1LPI						0x6C
#define SP_GRO_2LPI						0x6E
#define SP_GRO_4LPI						0x70
//Scale command
#define SP_SET_SCALE					0x72

//Communication
#define SP_COM_XON						0x11
#define SP_COM_XOFF						0x13

#define SP_COM_1200BPS					0xB1
#define SP_COM_2400BPS					0xB2
#define SP_COM_4800BPS					0xB3
#define SP_COM_9600BPS					0xB4
#define SP_COM_19200BPS					0xB5


//Other Commands
#define SP_GET_MODEL					0x05
#define SP_GET_PROTECTED_ID				0x08
#define SP_MOUSE_SYSTEM_EMULATION		0x4D
#define SP_MS_MOUSE_EMULATION			0x4E

#define SP_CMD_SELF_TEST				0x74
#define SP_CMD_SELF_TEST_RESULTS		0x77

#define SP_CMD_GET_CONFIGURATION		0x61

#define SP_CMD_RESET					0x00

#endif 